==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridSelectedKeysChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var GridSelectedKeysChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridSelectedKeysChangedEventArgsDescription, _super);
    function GridSelectedKeysChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.g = null;
        _this.f = null;
        _this.h = null;
        return _this;
    }
    GridSelectedKeysChangedEventArgsDescription.prototype.get_type = function () {
        return "GridSelectedKeysChangedEventArgs";
    };
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "currentKeys", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("CurrentKeys");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "addedKeys", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("AddedKeys");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "removedKeys", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("RemovedKeys");
        },
        enumerable: true,
        configurable: true
    });
    GridSelectedKeysChangedEventArgsDescription.$t = markType(GridSelectedKeysChangedEventArgsDescription, 'GridSelectedKeysChangedEventArgsDescription', Description.$);
    return GridSelectedKeysChangedEventArgsDescription;
}(Description));
export { GridSelectedKeysChangedEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridSelectedKeysChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var GridSelectedKeysChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedKeysChangedEventArgsDescription, _super);
    function GridSelectedKeysChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.i = null;
        _this.h = null;
        _this.j = null;
        return _this;
    }
    GridSelectedKeysChangedEventArgsDescription.prototype.get_type = function () {
        return "GridSelectedKeysChangedEventArgs";
    };
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "currentKeys", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("CurrentKeys");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "addedKeys", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("AddedKeys");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GridSelectedKeysChangedEventArgsDescription.prototype, "removedKeys", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("RemovedKeys");
        },
        enumerable: false,
        configurable: true
    });
    GridSelectedKeysChangedEventArgsDescription.$t = markType(GridSelectedKeysChangedEventArgsDescription, 'GridSelectedKeysChangedEventArgsDescription', Description.$);
    return GridSelectedKeysChangedEventArgsDescription;
}(Description));
export { GridSelectedKeysChangedEventArgsDescription };
